@@ -6,13 +6,13 @@ use utf8;
 package Dist::Zilla::Plugin::OSPrereqs;
 # ABSTRACT: List prereqs conditional on operating system
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 
 use Moose;
 use List::Util 1.33 'first';
 use namespace::autoclean;
 
-with 'Dist::Zilla::Role::InstallTool', 'Dist::Zilla::Role::MetaProvider';
+with 'Dist::Zilla::Role::FileMunger', 'Dist::Zilla::Role::MetaProvider';
 
 has prereq_os => (
     is       => 'ro',
@@ -42,12 +42,6 @@ has _prereq => (
     default => sub { {} },
 );
 
-has _builder => (
-    is      => 'rw',
-    isa     => 'Str',
-    default => 'makemaker',
-);
-
 has _prereq_str => (
     is      => 'ro',
     isa     => 'HashRef',
@@ -96,51 +90,49 @@ sub BUILDARGS {
     };
 }
 
-sub setup_installer {
+sub munge_files {
     my ($self) = @_;
+
     return unless my $os = $self->prereq_os;
 
-    # first, try MakeMaker
-    my $build_script = first { $_->name eq 'Makefile.PL' } @{ $self->zilla->files };
-    if ( !$build_script ) {
-        $build_script = first { $_->name eq 'Build.PL' } @{ $self->zilla->files };
-        if ($build_script) {
-            $self->_builder('modulebuild');
+    my @build_scripts = grep { $_->name eq 'Makefile.PL' or $_->name eq 'Build.PL' }
+      @{ $self->zilla->files };
+    $self->log_fatal(
+        'No Makefile.PL or Build.PL found! Is [MakeMaker] and [ModuleBuild] at least version 5.022?'
+    ) if not @build_scripts;
+
+    foreach my $build_script (@build_scripts) {
+        my $builder = $build_script->name eq 'Makefile.PL' ? 'makemaker' : 'modulebuild';
+        my $content = $build_script->content;
+
+        my $prereq_str;
+        if ( $os =~ /^!~(.+)/ ) {
+            $prereq_str = "if ( \$^O !~ /$1/i ) {\n";
+        }
+        elsif ( $os =~ /^!(.+)/ ) {
+            $prereq_str = "if ( \$^O ne '$1' ) {\n";
+        }
+        elsif ( $os =~ /^~(.+)/ ) {
+            $prereq_str = "if ( \$^O =~ /$1/i ) {\n";
         }
         else {
-            $self->log_fatal(
-                'No Build.PL or Makefile.PL found. Using either [MakeMaker] or [ModuleBuild] is required'
-            );
+            $prereq_str = "if ( \$^O eq '$os' ) {\n";
         }
+        my $prereq_hash = $self->_prereq;
+        for my $k ( sort keys %$prereq_hash ) {
+            my $v = $prereq_hash->{$k};
+            $prereq_str .= $self->_prereq_str->{$builder} . "{'$k'} = '$v';\n";
+        }
+        $prereq_str .= "}\n\n";
+
+        my $reg = $self->_builder_regex->{$builder};
+        $content =~ s/(?=$reg)/$prereq_str/
+          or $self->log_fatal("Failed to insert conditional prereq for $os");
+
+        return $build_script->content($content);
     }
 
-    my $content = $build_script->content;
-
-    my $prereq_str;
-    if ( $os =~ /^!~(.+)/ ) {
-        $prereq_str = "if ( \$^O !~ /$1/i ) {\n";
-    }
-    elsif ( $os =~ /^!(.+)/ ) {
-        $prereq_str = "if ( \$^O ne '$1' ) {\n";
-    }
-    elsif ( $os =~ /^~(.+)/ ) {
-        $prereq_str = "if ( \$^O =~ /$1/i ) {\n";
-    }
-    else {
-        $prereq_str = "if ( \$^O eq '$os' ) {\n";
-    }
-    my $prereq_hash = $self->_prereq;
-    for my $k ( sort keys %$prereq_hash ) {
-        my $v = $prereq_hash->{$k};
-        $prereq_str .= $self->_prereq_str->{ $self->_builder } . "{'$k'} = '$v';\n";
-    }
-    $prereq_str .= "}\n\n";
-
-    my $reg = $self->_builder_regex->{ $self->_builder };
-    $content =~ s/(?=$reg)/$prereq_str/
-      or $self->log_fatal("Failed to insert conditional prereq for $os");
-
-    return $build_script->content($content);
+    return 1;
 }
 
 sub metadata {
@@ -163,7 +155,7 @@ Dist::Zilla::Plugin::OSPrereqs - List prereqs conditional on operating system
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -194,7 +186,7 @@ must give the plugin a name corresponding to an operating system that would
 appear in C<$^O>.  Any prerequisites listed will be conditionally added to
 C<PREREQ_PM> in the Makefile.PL
 
-=for Pod::Coverage setup_installer metadata
+=for Pod::Coverage munge_files metadata
 
 =head1 WARNING
 
